@@ -42,7 +42,8 @@ typedef enum sebie_dirty_tag_e {
   SEBIE_UPDATE_INPUT_PATH       =   8,
   SEBIE_UPDATE_INPUT_REGEX      =  16,
   SEBIE_UPDATE_OUTPUT_FORMAT    =  32,
-  SEBIE_UPDATE_OUTPUT_FILE_NAME =  64
+  SEBIE_UPDATE_OUTPUT_FILE_NAME =  64,
+  SEBIE_UPDATE_STATUS_BAR       = 128
 } sebie_dirty_tag;
 
 typedef enum sebie_mouse_click_e {
@@ -80,6 +81,7 @@ typedef struct sebie_view_s {
   GtkWidget *treeview_file_list;
   GtkWidget *drawingarea1;
   GtkWidget *statusbar1;
+  guint statusbar1_context_id;
 } sebie_view;
 
 typedef struct sebie_model_s {
@@ -89,6 +91,8 @@ typedef struct sebie_model_s {
   char *output_format;
   char *input_file_name;
   char *output_file_name;
+  char *input_file_path;
+  char *output_file_path;
   regex_t regex;
   GtkListStore *file_list;
   /* orig image */
@@ -117,6 +121,8 @@ typedef struct sebie_model_s {
   gint selection_fac_width;
   gint selection_fac_height;
   gdouble selection_fac;
+  /* the status bar text */
+  gchar *statusbar_text;
 } sebie_model;
 
 
