@@ -19,9 +19,11 @@
  *
  */
 #include "sebie_callbacks.h"
+#include "sebie_helpers.h"
 #include "sebie_gtk_helpers.h"
 
 #include <stdio.h>
+#include <string.h>
 
 
 void
@@ -34,7 +36,7 @@ on_treeview_file_list_changed(GtkTreeSelection *selection,
   gchar *filename;
   if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
     gtk_tree_model_get(model, &iter, 0, &filename, -1);
-    sebie_set_input_file_name(sebie, filename);
+    sebie_set_string(&sebie->model.input_file_name, filename);
     load_pixbuf(sebie);
     int nmatch = 2;
     regmatch_t matchptr[nmatch];
@@ -48,7 +50,7 @@ on_treeview_file_list_changed(GtkTreeSelection *selection,
       }
       char buf[256];
       snprintf(buf, 256, sebie->model.output_format, buf_regex[1]);
-      sebie_set_output_file_name(sebie, buf);
+      sebie_set_string(&sebie->model.output_file_name, buf);
       sebie->dirty_tags |= SEBIE_UPDATE_OUTPUT_FILE_NAME;
       sebie_update_view(sebie);
     }
@@ -94,7 +96,7 @@ on_entry_output_format_changed (GtkEditable *editable,
   struct sebie_s *sebie = (struct sebie_s *)user_data;
   G_CONST_RETURN gchar *output_format = gtk_entry_get_text(GTK_ENTRY(editable));
   printf("output_format = %s\n", output_format);
-  sebie_set_output_format(sebie, output_format);
+  sebie_set_string(&sebie->model.output_format, output_format);
 }
 
 void
@@ -178,6 +180,7 @@ on_button_save_clicked (GtkButton *button,
     save = rotated;
   }
   GError *error = NULL;
+  
   gdk_pixbuf_save(save, sebie->model.output_file_name, "jpeg", &error, "quality", "85", NULL);
 
 }
